camelot.camelot.empty_project.model

Package camelot :: Package camelot :: Package empty_project :: Module model |
[hide private]
[frames] | no frames]

# Source Code for Module camelot.camelot.empty_project.model

    1

    2  import camelot.types
    3  from camelot.model import metadata, Entity, Field, ManyToOne, OneToMany, Unicode, Date, Integer, using_options
    4  from camelot.view.elixir_admin import EntityAdmin
    5  from camelot.view.forms import *
    6

    7  __metadata__ = metadata
    8